@@ -1,14 +1,14 @@
 ### R code from vignette source 'equatevignette.Rnw'
 
 ###################################################
-### code chunk number 1: equatevignette.Rnw:372-374
+### code chunk number 1: equatevignette.Rnw:375-377
 ###################################################
 op <- options()
 options(prompt = "R>", show.signif.stars = FALSE, warn = -1)
 
 
 ###################################################
-### code chunk number 2: equatevignette.Rnw:376-379
+### code chunk number 2: equatevignette.Rnw:379-382
 ###################################################
 library("equate")
 act.x <- as.freqtab(ACTmath[, 1:2])
@@ -16,21 +16,21 @@ act.y <- as.freqtab(ACTmath[, c(1, 3)])
 
 
 ###################################################
-### code chunk number 3: equatevignette.Rnw:382-384
+### code chunk number 3: equatevignette.Rnw:385-387
 ###################################################
 head(act.x)
 rbind(x = summary(act.x), y = summary(act.y))
 
 
 ###################################################
-### code chunk number 4: equatevignette.Rnw:387-389
+### code chunk number 4: equatevignette.Rnw:390-392
 ###################################################
 neat.x <- freqtab(KBneat$x, scales = list(0:36, 0:12))
 neat.y <- freqtab(KBneat$y, scales = list(0:36, 0:12))
 
 
 ###################################################
-### code chunk number 5: equatevignette.Rnw:393-403
+### code chunk number 5: equatevignette.Rnw:396-406
 ###################################################
 attach(PISA)
 r3items <- paste(items$itemid[items$clusterid == "r3a"])
@@ -45,7 +45,7 @@ round(data.frame(summary(pisa),
 
 
 ###################################################
-### code chunk number 6: equatevignette.Rnw:407-409
+### code chunk number 6: equatevignette.Rnw:410-412
 ###################################################
 plot(x = act.x, lwd = 2, xlab = "Score", ylab = "Count")
 plot(neat.x)
@@ -64,26 +64,26 @@ plot(neat.x)
 
 
 ###################################################
-### code chunk number 9: equatevignette.Rnw:419-420
+### code chunk number 9: equatevignette.Rnw:422-423
 ###################################################
 plot(x = act.x, lwd = 2, xlab = "Score", ylab = "Count")
 
 
 ###################################################
-### code chunk number 10: equatevignette.Rnw:429-430
+### code chunk number 10: equatevignette.Rnw:432-433
 ###################################################
 plot(neat.x)
 
 
 ###################################################
-### code chunk number 11: equatevignette.Rnw:441-443 (eval = FALSE)
+### code chunk number 11: equatevignette.Rnw:444-446 (eval = FALSE)
 ###################################################
 ## presmoothing(~ poly(total, 3, raw = T) + poly(anchor, 3, raw = T) +
 ## 	total:anchor, data = neat.x)
 
 
 ###################################################
-### code chunk number 12: equatevignette.Rnw:448-451 (eval = FALSE)
+### code chunk number 12: equatevignette.Rnw:451-454 (eval = FALSE)
 ###################################################
 ## neat.xsf <- with(as.data.frame(neat.x), cbind(total, total^2,
 ## 	total^3, anchor, anchor^2, anchor^3, total*anchor))
@@ -91,13 +91,13 @@ plot(neat.x)
 
 
 ###################################################
-### code chunk number 13: equatevignette.Rnw:456-457
+### code chunk number 13: equatevignette.Rnw:459-460
 ###################################################
 neat.xs <- presmoothing(neat.x, smooth = "log", degrees = list(3, 1))
 
 
 ###################################################
-### code chunk number 14: equatevignette.Rnw:462-467
+### code chunk number 14: equatevignette.Rnw:465-470
 ###################################################
 neat.xsmat <- presmoothing(neat.x, smooth = "loglinear",
 	degrees = list(3, 1), stepup = TRUE)
@@ -119,52 +119,58 @@ plot(neat.x, neat.xsmat, ylty = 1:5)
 
 
 ###################################################
-### code chunk number 17: equatevignette.Rnw:477-478
+### code chunk number 17: equatevignette.Rnw:480-481
 ###################################################
 plot(neat.xs)
 
 
 ###################################################
-### code chunk number 18: equatevignette.Rnw:487-488
+### code chunk number 18: equatevignette.Rnw:490-491
 ###################################################
 plot(neat.x, neat.xsmat, ylty = 1:5)
 
 
 ###################################################
-### code chunk number 19: equatevignette.Rnw:498-500
+### code chunk number 19: equatevignette.Rnw:501-503
 ###################################################
 presmoothing(neat.x, smooth = "loglinear",
 	degrees = list(c(3, 3), c(1, 1)), compare = TRUE)
 
 
 ###################################################
-### code chunk number 20: equatevignette.Rnw:505-506
+### code chunk number 20: equatevignette.Rnw:508-509
 ###################################################
 equate(act.x, act.y, type = "mean")
 
 
 ###################################################
-### code chunk number 21: equatevignette.Rnw:509-511
+### code chunk number 21: equatevignette.Rnw:512-514
 ###################################################
 neat.ef <- equate(neat.x, neat.y, type = "equip",
 	method = "frequency estimation", smoothmethod = "log")
 
 
 ###################################################
-### code chunk number 22: equatevignette.Rnw:516-517
+### code chunk number 22: equatevignette.Rnw:519-520
 ###################################################
 summary(neat.ef)
 
 
 ###################################################
-### code chunk number 23: equatevignette.Rnw:521-523
+### code chunk number 23: equatevignette.Rnw:524-526
 ###################################################
 cbind(newx = c(3, 29, 8, 7, 13),
 	yx = equate(c(3, 29, 8, 7, 13), y = neat.ef))
 
 
 ###################################################
-### code chunk number 24: equatevignette.Rnw:528-534
+### code chunk number 24: equatevignette.Rnw:529-530
+###################################################
+head(neat.ef$concordance)
+
+
+###################################################
+### code chunk number 25: equatevignette.Rnw:534-540
 ###################################################
 neat.i <- equate(neat.x, neat.y, type = "ident")
 neat.lt <- equate(neat.x, neat.y, type = "linear",
@@ -175,19 +181,19 @@ plot(neat.comp, addident = FALSE)
 
 
 ###################################################
-### code chunk number 25: plotcomposite
+### code chunk number 26: plotcomposite
 ###################################################
 plot(neat.comp, addident = FALSE)
 
 
 ###################################################
-### code chunk number 26: equatevignette.Rnw:543-544
+### code chunk number 27: equatevignette.Rnw:549-550
 ###################################################
 plot(neat.comp, addident = FALSE)
 
 
 ###################################################
-### code chunk number 27: equatevignette.Rnw:557-565
+### code chunk number 28: equatevignette.Rnw:563-571
 ###################################################
 pisa.i <- equate(pisa, type = "ident", lowp = c(3.5, 2))
 pisa.m <- equate(pisa, type = "mean", lowp = c(3.5, 2))
@@ -200,21 +206,21 @@ plot(pisa.i, pisa.m, pisa.l, pisa.c, pisa.e, addident = F,
 
 
 ###################################################
-### code chunk number 28: plotstudy2
+### code chunk number 29: plotstudy2
 ###################################################
 plot(pisa.i, pisa.m, pisa.l, pisa.c, pisa.e, addident = F,
 	xpoints = pisa, morepars = list(ylim = c(0, 31)))
 
 
 ###################################################
-### code chunk number 29: equatevignette.Rnw:573-574
+### code chunk number 30: equatevignette.Rnw:579-580
 ###################################################
 plot(pisa.i, pisa.m, pisa.l, pisa.c, pisa.e, addident = F,
 	xpoints = pisa, morepars = list(ylim = c(0, 31)))
 
 
 ###################################################
-### code chunk number 30: equatevignette.Rnw:585-589
+### code chunk number 31: equatevignette.Rnw:591-595
 ###################################################
 pisa.x <- freqtab(totals$b4[1:200, c("r3a", "r2", "s2")],
 	scales = list(0:15, 0:17, 0:18))
@@ -223,7 +229,7 @@ pisa.y <- freqtab(totals$b4[201:400, c("r4a", "r2", "s2")],
 
 
 ###################################################
-### code chunk number 31: equatevignette.Rnw:594-600
+### code chunk number 32: equatevignette.Rnw:600-606
 ###################################################
 pisa.mnom <- equate(pisa.x, pisa.y, type = "mean",
 	method = "nom")
@@ -234,7 +240,7 @@ pisa.mfreq <- equate(pisa.x, pisa.y, type = "equip",
 
 
 ###################################################
-### code chunk number 32: equatevignette.Rnw:603-609
+### code chunk number 33: equatevignette.Rnw:609-615
 ###################################################
 pisa.snom <- equate(margin(pisa.x, 1:2), margin(pisa.y, 1:2),
 	type = "mean", method = "nom")
@@ -245,7 +251,7 @@ pisa.sfreq <- equate(margin(pisa.x, 1:2), margin(pisa.y, 1:2),
 
 
 ###################################################
-### code chunk number 33: plotstudy3
+### code chunk number 34: plotstudy3
 ###################################################
 plot(pisa.snom, pisa.stuck, pisa.sfreq,
 	pisa.mnom, pisa.mtuck, pisa.mfreq,
@@ -253,7 +259,7 @@ plot(pisa.snom, pisa.stuck, pisa.sfreq,
 
 
 ###################################################
-### code chunk number 34: equatevignette.Rnw:619-620
+### code chunk number 35: equatevignette.Rnw:625-626
 ###################################################
 plot(pisa.snom, pisa.stuck, pisa.sfreq,
 	pisa.mnom, pisa.mtuck, pisa.mfreq,
@@ -261,7 +267,7 @@ plot(pisa.snom, pisa.stuck, pisa.sfreq,
 
 
 ###################################################
-### code chunk number 35: equatevignette.Rnw:635-643
+### code chunk number 36: equatevignette.Rnw:643-651
 ###################################################
 neat.xp <- presmoothing(neat.x, "loglinear", degrees = list(4, 2))
 neat.xpmat <- presmoothing(neat.x, "loglinear", degrees = list(4, 2),
@@ -274,31 +280,31 @@ plot(neat.y, neat.ypmat)
 
 
 ###################################################
-### code chunk number 36: plotstudy1x
+### code chunk number 37: plotstudy1x
 ###################################################
 plot(neat.x, neat.xpmat)
 
 
 ###################################################
-### code chunk number 37: plotstudy1y
+### code chunk number 38: plotstudy1y
 ###################################################
 plot(neat.y, neat.ypmat)
 
 
 ###################################################
-### code chunk number 38: equatevignette.Rnw:654-655
+### code chunk number 39: equatevignette.Rnw:662-663
 ###################################################
 plot(neat.x, neat.xpmat)
 
 
 ###################################################
-### code chunk number 39: equatevignette.Rnw:664-665
+### code chunk number 40: equatevignette.Rnw:672-673
 ###################################################
 plot(neat.y, neat.ypmat)
 
 
 ###################################################
-### code chunk number 40: equatevignette.Rnw:673-678
+### code chunk number 41: equatevignette.Rnw:681-686
 ###################################################
 set.seed(131031)
 reps <- 100
@@ -308,7 +314,7 @@ crit <- equate(neat.xp, neat.yp, "e", "c")$conc$yx
 
 
 ###################################################
-### code chunk number 41: equatevignette.Rnw:681-692
+### code chunk number 42: equatevignette.Rnw:689-700
 ###################################################
 neat.args <- list(i = list(type = "i"),
 	mt = list(type = "mean", method = "t"),
@@ -324,7 +330,7 @@ bootout <- bootstrap(x = neat.xp, y = neat.yp, xn = xn, yn = yn,
 
 
 ###################################################
-### code chunk number 42: equatevignette.Rnw:695-702
+### code chunk number 43: equatevignette.Rnw:703-710
 ###################################################
 plot(bootout, addident = F, col = c(1, rainbow(8)))
 plot(bootout, out = "se", addident = F,
@@ -336,68 +342,69 @@ plot(bootout, out = "rmse", addident = F, legendplace = "top",
 
 
 ###################################################
-### code chunk number 43: plotstudy1means
+### code chunk number 44: plotstudy1means
 ###################################################
 plot(bootout, addident = F, col = c(1, rainbow(8)))
 
 
 ###################################################
-### code chunk number 44: plotstudy1se
+### code chunk number 45: plotstudy1se
 ###################################################
 plot(bootout, out = "se", addident = F,
 	col = c(1, rainbow(8)), legendplace = "top")
 
 
 ###################################################
-### code chunk number 45: plotstudy1bias
+### code chunk number 46: plotstudy1bias
 ###################################################
 plot(bootout, out = "bias", addident = F, legendplace = "top",
 	col = c(1, rainbow(8)), morepars = list(ylim = c(-.9, 3)))
 
 
 ###################################################
-### code chunk number 46: plotstudy1rmse
+### code chunk number 47: plotstudy1rmse
 ###################################################
 plot(bootout, out = "rmse", addident = F, legendplace = "top",
 	col = c(1, rainbow(8)), morepars = list(ylim = c(0, 3)))
 
 
 ###################################################
-### code chunk number 47: equatevignette.Rnw:721-722
+### code chunk number 48: equatevignette.Rnw:729-730
 ###################################################
 plot(bootout, addident = F, col = c(1, rainbow(8)))
 
 
 ###################################################
-### code chunk number 48: equatevignette.Rnw:731-732
+### code chunk number 49: equatevignette.Rnw:739-740
 ###################################################
 plot(bootout, out = "se", addident = F,
 	col = c(1, rainbow(8)), legendplace = "top")
 
 
 ###################################################
-### code chunk number 49: equatevignette.Rnw:741-742
+### code chunk number 50: equatevignette.Rnw:749-750
 ###################################################
 plot(bootout, out = "bias", addident = F, legendplace = "top",
 	col = c(1, rainbow(8)), morepars = list(ylim = c(-.9, 3)))
 
 
 ###################################################
-### code chunk number 50: equatevignette.Rnw:751-752
+### code chunk number 51: equatevignette.Rnw:759-760
 ###################################################
 plot(bootout, out = "rmse", addident = F, legendplace = "top",
 	col = c(1, rainbow(8)), morepars = list(ylim = c(0, 3)))
 
 
 ###################################################
-### code chunk number 51: equatevignette.Rnw:760-761
+### code chunk number 52: equatevignette.Rnw:768-769
 ###################################################
 round(summary(bootout), 2)
 
 
 ###################################################
-### code chunk number 52: equatevignette.Rnw:763-764
+### code chunk number 53: equatevignette.Rnw:771-773
 ###################################################
+detach(PISA)
 options(op)
 
 
